summaryrefslogtreecommitdiff
path: root/innobase/include/os0file.h
diff options
context:
space:
mode:
Diffstat (limited to 'innobase/include/os0file.h')
-rw-r--r--innobase/include/os0file.h3
1 files changed, 1 insertions, 2 deletions
diff --git a/innobase/include/os0file.h b/innobase/include/os0file.h
index b221bf7aef9..108cf5520f1 100644
--- a/innobase/include/os0file.h
+++ b/innobase/include/os0file.h
@@ -443,8 +443,7 @@ Prints info of the aio arrays. */
void
os_aio_print(
/*=========*/
- char* buf, /* in/out: buffer where to print */
- char* buf_end);/* in: buffer end */
+ FILE* file); /* in: file where to print */
/**************************************************************************
Refreshes the statistics used to print per-second averages. */